@@ -46,7 +46,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.3.1"
+VERSION = "0.3.2"
 
 class StarryError(Exception):
     def __init__(self, output):
@@ -240,17 +240,17 @@ class StarryServer(object):
                     try:
                         conn = listener.accept()
                     except OSError as e:
-                        self.logger.warn(f"Caught exception: {e.__class__}({e})")
+                        self.logger.warn(f"Caught exception: {e.__doc__}({e})")
                         break
                     except Exception as e:
-                        self.logger.warn(f"Caught exception: {e.__class__}({e})")
+                        self.logger.warn(f"Caught exception: {e.__doc__}({e})")
                         continue
 
                     try:
                         tlock = conn.recv()
                         executor.submit(self._callableForward, conn, tlock)
                     except Exception as e:
-                        self.logger.error(f"Caught exception: {e.__class__}({e})")
+                        self.logger.error(f"Caught exception: {e.__doc__}({e})")
 
                         try:
                             conn.close()
@@ -268,10 +268,10 @@ class StarryServer(object):
                 try:
                     conn.send(eval(f"self.{func}")(*param))
                 except Exception as e:
-                    self.logger.debug(f"Caught exception: {e.__class__}({e})")
+                    self.logger.debug(f"Caught exception: {e.__doc__}({e})")
 
                     try:
-                        conn.send((False, f"Caught exception: {e.__class__}({e})"))
+                        conn.send((False, f"Caught exception: {e.__doc__}({e})"))
                     except:
                         pass
 
@@ -287,10 +287,10 @@ class StarryServer(object):
                     try:
                         conn.send(eval(f"self.{func}")(*param))
                     except Exception as e:
-                        self.logger.debug(f"Caught exception: {e.__class__}({e})")
+                        self.logger.debug(f"Caught exception: {e.__doc__}({e})")
 
                         try:
-                            conn.send((False, f"Caught exception: {e.__class__}({e})"))
+                            conn.send((False, f"Caught exception: {e.__doc__}({e})"))
                         except:
                             pass
 
@@ -613,14 +613,14 @@ class StarryServer(object):
                 try:
                     elem.unlink()
                 except Exception as e:
-                    self.logger.error(f"Caught exception: {e.__class__}({e})")
-                    return (False, f"Caught exception: {e.__class__}({e})")
+                    self.logger.error(f"Caught exception: {e.__doc__}({e})")
+                    return (False, f"Caught exception: {e.__doc__}({e})")
             elif elem.isdir():
                 try:
                     shutil.rmtree(elem)
                 except Exception as e:
-                    self.logger.error(f"Caught exception: {e.__class__}({e})")
-                    return (False, f"Caught exception: {e.__class__}({e})")
+                    self.logger.error(f"Caught exception: {e.__doc__}({e})")
+                    return (False, f"Caught exception: {e.__doc__}({e})")
 
         try:
             self.cache.flush_all()
@@ -637,8 +637,8 @@ class StarryServer(object):
             try:
                 shutil.rmtree(self.database)
             except Exception as e:
-                self.logger.error(f"Caught exception: {e.__class__}({e})")
-                return (False, f"Caught exception: {e.__class__}({e})")
+                self.logger.error(f"Caught exception: {e.__doc__}({e})")
+                return (False, f"Caught exception: {e.__doc__}({e})")
 
         self.clear()
         self = []
@@ -734,7 +734,7 @@ class StarryServer(object):
                     except:
                         pass
 
-                    return (False, f"Caught exception: {e.__class__}({e})")
+                    return (False, f"Caught exception: {e.__doc__}({e})")
             elif self._getCache(key) == part:
                 return (True, "")
 
@@ -756,7 +756,7 @@ class StarryServer(object):
                 value = msgpack.unpackb(value, strict_map_key=False)
             except Exception as e:
                 self._recover(key)
-                return (False, f"Caught exception: {e.__class__}({e})")
+                return (False, f"Caught exception: {e.__doc__}({e})")
 
             (ret, msg) = _updatePart(value, branch, part)
             if ret is False:
@@ -767,7 +767,7 @@ class StarryServer(object):
         try:
             value = msgpack.packb(value)
         except Exception as e:
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         (ret, msg) = _writeFile(file, value)
         if ret is False:
@@ -802,7 +802,7 @@ class StarryServer(object):
                 value = msgpack.unpackb(value, strict_map_key=False)
             except Exception as e:
                 self._recover(key)
-                return (False, f"Caught exception: {e.__class__}({e})")
+                return (False, f"Caught exception: {e.__doc__}({e})")
 
             (ret, msg) = _insertPart(value, branch, part)
             if ret is False:
@@ -813,7 +813,7 @@ class StarryServer(object):
         try:
             value = msgpack.packb(value)
         except Exception as e:
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         if not file.exists():
             try:
@@ -824,7 +824,7 @@ class StarryServer(object):
                 except:
                     pass
 
-                return (False, f"Caught exception: {e.__class__}({e})")
+                return (False, f"Caught exception: {e.__doc__}({e})")
 
         (ret, msg) = _writeFile(file, value)
         if ret is False:
@@ -882,7 +882,7 @@ class StarryServer(object):
                 file.unlink()
             except Exception as e:
                 self._recover(key)
-                return (False, f"Caught exception: {e.__class__}({e})")
+                return (False, f"Caught exception: {e.__doc__}({e})")
 
             try:
                 backup_file.unlink()
@@ -904,7 +904,7 @@ class StarryServer(object):
             value = msgpack.unpackb(value, strict_map_key=False)
         except Exception as e:
             self._recover(key)
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         (ret, msg) = _deletePart(value, branch)
         if ret is False:
@@ -913,7 +913,7 @@ class StarryServer(object):
         try:
             value = msgpack.packb(value)
         except Exception as e:
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         (ret, msg) = _writeFile(file, value)
         if ret is False:
@@ -939,7 +939,7 @@ class StarryServer(object):
                 msgpack.unpackb(data, strict_map_key=False)
             except Exception as e:
                 self._recover(key)
-                return (False, f"Caught exception: {e.__class__}({e})")
+                return (False, f"Caught exception: {e.__doc__}({e})")
 
         if path is None:
             path = self.database.joinpath(".backup")
@@ -971,7 +971,7 @@ class StarryServer(object):
             except:
                 pass
 
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         (ret, msg) = _copyFile(backup_file, self.database.joinpath(f"{key}.mpb"))
         if ret is False:
@@ -996,7 +996,7 @@ class StarryServer(object):
         try:
             msgpack.unpackb(value, strict_map_key=False)
         except Exception as e:
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         if file.exists():
             if not backup_file.exists():
@@ -1114,7 +1114,7 @@ class StarryClient(object):
         try:
             self.client.send((func, *args))
         except Exception as e:
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
         try:
             if self.client.poll(60):
@@ -1122,7 +1122,7 @@ class StarryClient(object):
             else:
                 return (False, "timeout")
         except Exception as e:
-            return (False, f"Caught exception: {e.__class__}({e})")
+            return (False, f"Caught exception: {e.__doc__}({e})")
 
     def get(self, key):
         return self._callableForward("get", key)
@@ -1239,12 +1239,12 @@ def _getPart(value, branch, filters):
                 try:
                     value = value[knot]
                 except Exception as e:
-                    return (False, f"Caught exception: {e.__class__}({e})")
+                    return (False, f"Caught exception: {e.__doc__}({e})")
             elif all([type(v) is dict for v in value]):
                 try:
                     value = [v[knot] for v in value if knot in v]
                 except Exception as e:
-                    return (False, f"Caught exception: {e.__class__}({e})")
+                    return (False, f"Caught exception: {e.__doc__}({e})")
             else:
                 return (False, f"Syntax error.")
         elif type(value) is dict and knot in value:
@@ -1351,7 +1351,7 @@ def _readFile(src):
     try:
         return (True, src.read_bytes())
     except Exception as e:
-        return (False, f"Caught exception: {e.__class__}({e})")
+        return (False, f"Caught exception: {e.__doc__}({e})")
 
 def _writeFile(dst, value):
     try:
@@ -1365,7 +1365,7 @@ def _writeFile(dst, value):
         if len(value) != dst.stat().st_size:
             return (False, "No space left on device.")
     except Exception as e:
-        return (False, f"Caught exception: {e.__class__}({e})")
+        return (False, f"Caught exception: {e.__doc__}({e})")
 
     return (True, "")
 
